@@ -51,5 +51,8 @@ class Retriable(Module):
         **kwargs,
     ):
         super().__init__(module_id=module_id, **kwargs)
-        self.schedule = schedule or [180, 60]
+
+        max_retries = 180
+        interval = 60
+        self.schedule = schedule or [max_retries, interval]
 
