@@ -14,8 +14,8 @@ from twilio.rest import Client
 from twilio.base.exceptions import TwilioRestException
 
 
-PIPELINE_EMAIL_MODULE_NAME = "alira.modules.notification.email"
-PIPELINE_SMS_MODULE_NAME = "alira.modules.notification.sms"
+PIPELINE_EMAIL_MODULE_NAME = "email"
+PIPELINE_SMS_MODULE_NAME = "sms"
 
 
 class Notification(Retriable):
@@ -39,7 +39,7 @@ class Notification(Retriable):
         ) as file:
             template = file.read()
 
-        variables_pattern = re.compile(r"\[\[([A-Za-z0-9_.]+)\]\]")
+        variables_pattern = re.compile(r"\[\[([A-Za-z0-9_.\"]+)\]\]")
 
         variables = variables_pattern.findall(template)
         for variable in variables:
