@@ -10,7 +10,7 @@ from alira.modules.module import Retriable
 
 from botocore.exceptions import EndpointConnectionError
 
-PIPELINE_MODULE_NAME = "alira.modules.s3"
+PIPELINE_MODULE_NAME = "s3"
 
 
 class S3(Retriable):
@@ -103,12 +103,12 @@ class S3(Retriable):
 
             result = {
                 "status": "SUCCESS",
-                "s3_file_url": f"s3://{self.aws_s3_bucket}/{s3_key}",
+                "file_url": f"s3://{self.aws_s3_bucket}/{s3_key}",
             }
 
             if self.aws_s3_public:
                 result[
-                    "s3_file_public_url"
+                    "public_url"
                 ] = f"https://{self.aws_s3_bucket}.s3.amazonaws.com/{s3_key}"
 
             return result
